@@ -20,7 +20,7 @@
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Headers
+// TQt Headers
 
 #include <tqfile.h>
 #include <tqregexp.h>
@@ -28,7 +28,7 @@
 #include <tqprocess.h>
 
 // ----------------------------------------------------------------------------
-// KDE Headers
+// TDE Headers
 
 #include <tdeio/netaccess.h>
 #include <tdeio/scheduler.h>
@@ -61,7 +61,7 @@ WebPriceQuote::WebPriceQuote( TQObject* _parent, const char* _name ):
 {
   m_financeQuoteScriptPath =
       TDEGlobal::dirs()->findResource("appdata", TQString("misc/financequote.pl"));
-  connect(&m_filter,TQT_SIGNAL(processExited(const TQString&)),this,TQT_SLOT(slotParseQuote(const TQString&)));
+  connect(&m_filter,TQ_SIGNAL(processExited(const TQString&)),this,TQ_SLOT(slotParseQuote(const TQString&)));
 }
 
 WebPriceQuote::~WebPriceQuote()
@@ -222,8 +222,8 @@ bool WebPriceQuote::download(const KURL& u, TQString & target, TQWidget* window)
   TDEIO::Job * job = TDEIO::file_copy( u, dest, -1, true, false, false );
   job->setWindow (window);
   job->addMetaData("cache", "reload");  // bypass cache
-  connect( job, TQT_SIGNAL( result (TDEIO::Job *) ),
-           this, TQT_SLOT( slotResult (TDEIO::Job *) ) );
+  connect( job, TQ_SIGNAL( result (TDEIO::Job *) ),
+           this, TQ_SLOT( slotResult (TDEIO::Job *) ) );
 
   enter_loop();
   return bJobOK;
@@ -239,7 +239,7 @@ void tqt_leave_modal( TQWidget *widget );
 void WebPriceQuote::enter_loop(void)
 {
   TQWidget dummy(0,0,WType_Dialog | WShowModal);
-  dummy.setFocusPolicy( TQ_NoFocus );
+  dummy.setFocusPolicy( TQWidget::NoFocus );
   tqt_enter_modal(&dummy);
   tqApp->enter_loop();
   tqt_leave_modal(&dummy);
@@ -731,8 +731,8 @@ void WebPriceQuoteSource::remove(void) const
 
 WebPriceQuoteProcess::WebPriceQuoteProcess(void)
 {
-  connect(this, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(slotReceivedDataFromFilter(TDEProcess*, char*, int)));
-  connect(this, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotProcessExited(TDEProcess*)));
+  connect(this, TQ_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQ_SLOT(slotReceivedDataFromFilter(TDEProcess*, char*, int)));
+  connect(this, TQ_SIGNAL(processExited(TDEProcess*)), this, TQ_SLOT(slotProcessExited(TDEProcess*)));
 }
 
 void WebPriceQuoteProcess::slotReceivedDataFromFilter(TDEProcess* /*_process*/, char* _pcbuffer, int _nbufferlen)
@@ -813,8 +813,8 @@ FinanceQuoteProcess::FinanceQuoteProcess(void)
   m_fqNames["yahoo_europe"] = "Yahoo Europe";
   m_fqNames["yahoo_nz"] = "Yahoo New Zealand";
   m_fqNames["zifunds"] = "Zuerich Investments";
-  connect(this, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(slotReceivedDataFromFilter(TDEProcess*, char*, int)));
-  connect(this, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotProcessExited(TDEProcess*)));
+  connect(this, TQ_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQ_SLOT(slotReceivedDataFromFilter(TDEProcess*, char*, int)));
+  connect(this, TQ_SIGNAL(processExited(TDEProcess*)), this, TQ_SLOT(slotProcessExited(TDEProcess*)));
 }
 
 void FinanceQuoteProcess::slotReceivedDataFromFilter(TDEProcess* /*_process*/, char* _pcbuffer, int _nbufferlen)
@@ -1017,12 +1017,12 @@ TQDate MyMoneyDateFormat::convertString(const TQString& _in, bool _strict, unsig
 convertertest::QuoteReceiver::QuoteReceiver(WebPriceQuote* q, TQObject* parent, const char *name) :
   TQObject(parent,name)
 {
-  connect(q,TQT_SIGNAL(quote(const TQString&,const TQDate&, const double&)),
-    this,TQT_SLOT(slotGetQuote(const TQString&,const TQDate&, const double&)));
-  connect(q,TQT_SIGNAL(status(const TQString&)),
-    this,TQT_SLOT(slotStatus(const TQString&)));
-  connect(q,TQT_SIGNAL(error(const TQString&)),
-    this,TQT_SLOT(slotError(const TQString&)));
+  connect(q,TQ_SIGNAL(quote(const TQString&,const TQDate&, const double&)),
+    this,TQ_SLOT(slotGetQuote(const TQString&,const TQDate&, const double&)));
+  connect(q,TQ_SIGNAL(status(const TQString&)),
+    this,TQ_SLOT(slotStatus(const TQString&)));
+  connect(q,TQ_SIGNAL(error(const TQString&)),
+    this,TQ_SLOT(slotError(const TQString&)));
 }
 
 convertertest::QuoteReceiver::~QuoteReceiver()
