@@ -22,7 +22,7 @@
 #include <typeinfo>
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqlabel.h>
 #include <tqapplication.h>
@@ -31,7 +31,7 @@
 #include <tqbuttongroup.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <ktextedit.h>
 #include <tdelocale.h>
@@ -198,45 +198,45 @@ void InvestTransactionEditor::createEditWidgets(void)
 {
   KMyMoneyActivityCombo* activity = new KMyMoneyActivityCombo();
   m_editWidgets["activity"] = activity;
-  connect(activity, TQT_SIGNAL(activitySelected(MyMoneySplit::investTransactionTypeE)), this, TQT_SLOT(slotUpdateActivity(MyMoneySplit::investTransactionTypeE)));
-  connect(activity, TQT_SIGNAL(activitySelected(MyMoneySplit::investTransactionTypeE)), this, TQT_SLOT(slotUpdateButtonState()));
+  connect(activity, TQ_SIGNAL(activitySelected(MyMoneySplit::investTransactionTypeE)), this, TQ_SLOT(slotUpdateActivity(MyMoneySplit::investTransactionTypeE)));
+  connect(activity, TQ_SIGNAL(activitySelected(MyMoneySplit::investTransactionTypeE)), this, TQ_SLOT(slotUpdateButtonState()));
 
   m_editWidgets["postdate"] = new kMyMoneyDateInput;
-  connect(m_editWidgets["postdate"], TQT_SIGNAL(dateChanged(const TQDate&)), this, TQT_SLOT(slotUpdateButtonState()));
+  connect(m_editWidgets["postdate"], TQ_SIGNAL(dateChanged(const TQDate&)), this, TQ_SLOT(slotUpdateButtonState()));
 
   KMyMoneySecurity* security = new KMyMoneySecurity;
   security->setHint(i18n("Security"));
   m_editWidgets["security"] = security;
-  connect(security, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotUpdateSecurity(const TQString&)));
-  connect(security, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(security, TQT_SIGNAL(createItem(const TQString&, TQString&)), this, TQT_SLOT(slotCreateSecurity(const TQString&, TQString&)));
-  connect(security, TQT_SIGNAL(objectCreation(bool)), this, TQT_SIGNAL(objectCreation(bool)));
+  connect(security, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotUpdateSecurity(const TQString&)));
+  connect(security, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(security, TQ_SIGNAL(createItem(const TQString&, TQString&)), this, TQ_SLOT(slotCreateSecurity(const TQString&, TQString&)));
+  connect(security, TQ_SIGNAL(objectCreation(bool)), this, TQ_SIGNAL(objectCreation(bool)));
 
   KMyMoneyCategory* asset = new KMyMoneyCategory(0, 0, false);
   asset->setHint(i18n("Asset account"));
   m_editWidgets["asset-account"] = asset;
-  connect(asset, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(asset, TQT_SIGNAL(objectCreation(bool)), this, TQT_SIGNAL(objectCreation(bool)));
+  connect(asset, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(asset, TQ_SIGNAL(objectCreation(bool)), this, TQ_SIGNAL(objectCreation(bool)));
 
   KMyMoneyCategory* fees = new KMyMoneyCategory(0, 0, true);
   fees->setHint(i18n("Fees"));
   m_editWidgets["fee-account"] = fees;
-  connect(fees, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotUpdateFeeCategory(const TQString&)));
-  connect(fees, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(fees, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateFeeVisibility(const TQString&)));
-  connect(fees, TQT_SIGNAL(createItem(const TQString&, TQString&)), this, TQT_SLOT(slotCreateFeeCategory(const TQString&, TQString&)));
-  connect(fees, TQT_SIGNAL(objectCreation(bool)), this, TQT_SIGNAL(objectCreation(bool)));
-  connect(fees->splitButton(), TQT_SIGNAL(clicked()), this, TQT_SLOT(slotEditFeeSplits()));
+  connect(fees, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotUpdateFeeCategory(const TQString&)));
+  connect(fees, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(fees, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateFeeVisibility(const TQString&)));
+  connect(fees, TQ_SIGNAL(createItem(const TQString&, TQString&)), this, TQ_SLOT(slotCreateFeeCategory(const TQString&, TQString&)));
+  connect(fees, TQ_SIGNAL(objectCreation(bool)), this, TQ_SIGNAL(objectCreation(bool)));
+  connect(fees->splitButton(), TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEditFeeSplits()));
 
   KMyMoneyCategory* interest = new KMyMoneyCategory(0, 0, true);
   interest->setHint(i18n("Interest"));
   m_editWidgets["interest-account"] = interest;
-  connect(interest, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotUpdateInterestCategory(const TQString&)));
-  connect(interest, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(interest, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateInterestVisibility(const TQString&)));
-  connect(interest, TQT_SIGNAL(createItem(const TQString&, TQString&)), this, TQT_SLOT(slotCreateInterestCategory(const TQString&, TQString&)));
-  connect(interest, TQT_SIGNAL(objectCreation(bool)), this, TQT_SIGNAL(objectCreation(bool)));
-  connect(interest->splitButton(), TQT_SIGNAL(clicked()), this, TQT_SLOT(slotEditInterestSplits()));
+  connect(interest, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotUpdateInterestCategory(const TQString&)));
+  connect(interest, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(interest, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateInterestVisibility(const TQString&)));
+  connect(interest, TQ_SIGNAL(createItem(const TQString&, TQString&)), this, TQ_SLOT(slotCreateInterestCategory(const TQString&, TQString&)));
+  connect(interest, TQ_SIGNAL(objectCreation(bool)), this, TQ_SIGNAL(objectCreation(bool)));
+  connect(interest->splitButton(), TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEditInterestSplits()));
 
   KTextEdit* memo = new KTextEdit;
   memo->setTabChangesFocus(true);
@@ -246,36 +246,36 @@ void InvestTransactionEditor::createEditWidgets(void)
   value->setHint(i18n("Shares"));
   value->setResetButtonVisible(false);
   m_editWidgets["shares"] = value;
-  connect(value, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(value, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotUpdateTotalAmount()));
+  connect(value, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(value, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotUpdateTotalAmount()));
 
   value = new kMyMoneyEdit;
   value->setHint(i18n("Price"));
   value->setResetButtonVisible(false);
   value->setPrecision(KMyMoneyGlobalSettings::pricePrecision());
   m_editWidgets["price"] = value;
-  connect(value, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(value, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotUpdateTotalAmount()));
+  connect(value, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(value, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotUpdateTotalAmount()));
 
   value = new kMyMoneyEdit;
   // TODO once we have the selected transactions as array of Transaction
   // we can allow multiple splits for fee and interest
   value->setResetButtonVisible(false);
   m_editWidgets["fee-amount"] = value;
-  connect(value, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(value, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotUpdateTotalAmount()));
+  connect(value, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(value, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotUpdateTotalAmount()));
 
   value = new kMyMoneyEdit;
   // TODO once we have the selected transactions as array of Transaction
   // we can allow multiple splits for fee and interest
   value->setResetButtonVisible(false);
   m_editWidgets["interest-amount"] = value;
-  connect(value, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
-  connect(value, TQT_SIGNAL(valueChanged(const TQString&)), this, TQT_SLOT(slotUpdateTotalAmount()));
+  connect(value, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
+  connect(value, TQ_SIGNAL(valueChanged(const TQString&)), this, TQ_SLOT(slotUpdateTotalAmount()));
 
   KMyMoneyReconcileCombo* reconcile = new KMyMoneyReconcileCombo;
   m_editWidgets["status"] = reconcile;
-  connect(reconcile, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotUpdateButtonState()));
+  connect(reconcile, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotUpdateButtonState()));
 
   KMyMoneyRegister::TQWidgetContainer::iterator it_w;
   for(it_w = m_editWidgets.begin(); it_w != m_editWidgets.end(); ++it_w) {
@@ -327,12 +327,12 @@ void InvestTransactionEditor::createEditWidgets(void)
 
 int InvestTransactionEditor::slotEditFeeSplits(void)
 {
-  return editSplits("fee-account", "fee-amount", m_feeSplits, false, TQT_SLOT(slotEditFeeSplits()));
+  return editSplits("fee-account", "fee-amount", m_feeSplits, false, TQ_SLOT(slotEditFeeSplits()));
 }
 
 int InvestTransactionEditor::slotEditInterestSplits(void)
 {
-  return editSplits("interest-account", "interest-amount", m_interestSplits, true, TQT_SLOT(slotEditInterestSplits()));
+  return editSplits("interest-account", "interest-amount", m_interestSplits, true, TQ_SLOT(slotEditInterestSplits()));
 }
 
 int InvestTransactionEditor::editSplits(const TQString& categoryWidgetName, const TQString& amountWidgetName, TQValueList<MyMoneySplit>& splits, bool isIncome, const char* slotEditSplits)
@@ -381,7 +381,7 @@ int InvestTransactionEditor::editSplits(const TQString& categoryWidgetName, cons
                                                           0,
                                                           m_priceInfo,
                                                           m_regForm);
-      // connect(dlg, TQT_SIGNAL(newCategory(MyMoneyAccount&)), this, TQT_SIGNAL(newCategory(MyMoneyAccount&)));
+      // connect(dlg, TQ_SIGNAL(newCategory(MyMoneyAccount&)), this, TQ_SIGNAL(newCategory(MyMoneyAccount&)));
 
       if((rc = dlg->exec()) == TQDialog::Accepted) {
         transaction = dlg->transaction();
@@ -529,13 +529,13 @@ void InvestTransactionEditor::slotReloadEditWidgets(void)
   aSet.clear();
   aSet.addAccountGroup(MyMoneyAccount::Income);
   aSet.load(interest->selector());
-  setupCategoryWidget(interest, m_interestSplits, id, TQT_SLOT(slotEditInterestSplits()));
+  setupCategoryWidget(interest, m_interestSplits, id, TQ_SLOT(slotEditInterestSplits()));
 
   // fee-account
   aSet.clear();
   aSet.addAccountGroup(MyMoneyAccount::Expense);
   aSet.load(fees->selector());
-  setupCategoryWidget(fees, m_feeSplits, id, TQT_SLOT(slotEditFeeSplits()));
+  setupCategoryWidget(fees, m_feeSplits, id, TQ_SLOT(slotEditFeeSplits()));
 
   // security
   aSet.clear();
@@ -609,14 +609,14 @@ void InvestTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action /* action
     aSet.clear();
     aSet.addAccountGroup(MyMoneyAccount::Income);
     aSet.load(interest->selector());
-    setupCategoryWidget(interest, m_interestSplits, id, TQT_SLOT(slotEditInterestSplits()));
+    setupCategoryWidget(interest, m_interestSplits, id, TQ_SLOT(slotEditInterestSplits()));
     slotUpdateInterestVisibility(interest->currentText());
 
     // fee-account
     aSet.clear();
     aSet.addAccountGroup(MyMoneyAccount::Expense);
     aSet.load(fees->selector());
-    setupCategoryWidget(fees, m_feeSplits, id, TQT_SLOT(slotEditFeeSplits()));
+    setupCategoryWidget(fees, m_feeSplits, id, TQ_SLOT(slotEditFeeSplits()));
     slotUpdateFeeVisibility(fees->currentText());
 
     // memo
