@@ -15,8 +15,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqtimer.h>
 #include <tqwidgetlist.h>
@@ -26,10 +30,10 @@
 #include <tqvaluevector.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kpushbutton.h>
 #include <kstdguiitem.h>
 #include <klineedit.h>
@@ -71,7 +75,7 @@ KEditScheduleDlg::KEditScheduleDlg(const MyMoneySchedule& schedule, TQWidget *pa
   buttonCancel->setGuiItem(KStdGuiItem::cancel());
   buttonHelp->setGuiItem(KStdGuiItem::help());
 
-  d->m_requiredFields = new kMandatoryFieldGroup (TQT_TQOBJECT(this));
+  d->m_requiredFields = new kMandatoryFieldGroup (this);
   d->m_requiredFields->setOkButton(buttonOk); // button to be enabled when all fields present
 
   // make sure, we have a tabbar with the form
@@ -140,18 +144,18 @@ KEditScheduleDlg::KEditScheduleDlg(const MyMoneySchedule& schedule, TQWidget *pa
     m_FinalPaymentEdit->setDate(d->m_schedule.endDate());
   }
 
-  connect(m_RemainingEdit, TQT_SIGNAL(valueChanged(int)),
-    this, TQT_SLOT(slotRemainingChanged(int)));
-  connect(m_FinalPaymentEdit, TQT_SIGNAL(dateChanged(const TQDate&)),
-    this, TQT_SLOT(slotEndDateChanged(const TQDate&)));
-  connect(m_frequencyEdit, TQT_SIGNAL(itemSelected(int)),
-    this, TQT_SLOT(slotFrequencyChanged(int)));
-  connect(m_frequencyNoEdit, TQT_SIGNAL(valueChanged(int)),
-    this, TQT_SLOT(slotOccurenceMultiplierChanged(int)));
-  connect(buttonHelp, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotShowHelp()));
+  connect(m_RemainingEdit, TQ_SIGNAL(valueChanged(int)),
+    this, TQ_SLOT(slotRemainingChanged(int)));
+  connect(m_FinalPaymentEdit, TQ_SIGNAL(dateChanged(const TQDate&)),
+    this, TQ_SLOT(slotEndDateChanged(const TQDate&)));
+  connect(m_frequencyEdit, TQ_SIGNAL(itemSelected(int)),
+    this, TQ_SLOT(slotFrequencyChanged(int)));
+  connect(m_frequencyNoEdit, TQ_SIGNAL(valueChanged(int)),
+    this, TQ_SLOT(slotOccurenceMultiplierChanged(int)));
+  connect(buttonHelp, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotShowHelp()));
 
   // force the initial height to be as small as possible
-  TQTimer::singleShot(0, this, TQT_SLOT(slotSetupSize()));
+  TQTimer::singleShot(0, this, TQ_SLOT(slotSetupSize()));
 
   // we just hide the variation field for now and enable the logic
   // once we have a respective member in the MyMoneySchedule object
@@ -186,16 +190,16 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
   }
 
   if(editor) {
-    connect(editor, TQT_SIGNAL(transactionDataSufficient(bool)), buttonOk, TQT_SLOT(setEnabled(bool)));
-    connect(editor, TQT_SIGNAL(escapePressed()), buttonCancel, TQT_SLOT(animateClick()));
-    connect(editor, TQT_SIGNAL(returnPressed()), buttonOk, TQT_SLOT(animateClick()));
+    connect(editor, TQ_SIGNAL(transactionDataSufficient(bool)), buttonOk, TQ_SLOT(setEnabled(bool)));
+    connect(editor, TQ_SIGNAL(escapePressed()), buttonCancel, TQ_SLOT(animateClick()));
+    connect(editor, TQ_SIGNAL(returnPressed()), buttonOk, TQ_SLOT(animateClick()));
 
-    connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), editor, TQT_SLOT(slotReloadEditWidgets()));
-    // connect(editor, TQT_SIGNAL(finishEdit(const KMyMoneyRegister::SelectedTransactions&)), this, TQT_SLOT(slotLeaveEditMode(const KMyMoneyRegister::SelectedTransactions&)));
-    connect(editor, TQT_SIGNAL(createPayee(const TQString&, TQString&)), kmymoney2, TQT_SLOT(slotPayeeNew(const TQString&, TQString&)));
-    connect(editor, TQT_SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQT_SLOT(slotCategoryNew(MyMoneyAccount&, const MyMoneyAccount&)));
-    connect(editor, TQT_SIGNAL(createSecurity(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQT_SLOT(slotInvestmentNew(MyMoneyAccount&, const MyMoneyAccount&)));
-    connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), editor, TQT_SLOT(slotReloadEditWidgets()));
+    connect(MyMoneyFile::instance(), TQ_SIGNAL(dataChanged()), editor, TQ_SLOT(slotReloadEditWidgets()));
+    // connect(editor, TQ_SIGNAL(finishEdit(const KMyMoneyRegister::SelectedTransactions&)), this, TQ_SLOT(slotLeaveEditMode(const KMyMoneyRegister::SelectedTransactions&)));
+    connect(editor, TQ_SIGNAL(createPayee(const TQString&, TQString&)), kmymoney2, TQ_SLOT(slotPayeeNew(const TQString&, TQString&)));
+    connect(editor, TQ_SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQ_SLOT(slotCategoryNew(MyMoneyAccount&, const MyMoneyAccount&)));
+    connect(editor, TQ_SIGNAL(createSecurity(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQ_SLOT(slotInvestmentNew(MyMoneyAccount&, const MyMoneyAccount&)));
+    connect(MyMoneyFile::instance(), TQ_SIGNAL(dataChanged()), editor, TQ_SLOT(slotReloadEditWidgets()));
 
     // create the widgets, place them in the parent and load them with data
     // setup tab order
@@ -277,7 +281,7 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
     // connect the postdate modification signal to our update routine
     kMyMoneyDateInput* dateEdit = dynamic_cast<kMyMoneyDateInput*>(editor->haveWidget("postdate"));
     if(dateEdit)
-      connect(dateEdit, TQT_SIGNAL(dateChanged(const TQDate&)), this, TQT_SLOT(slotPostDateChanged(const TQDate&)));
+      connect(dateEdit, TQ_SIGNAL(dateChanged(const TQDate&)), this, TQ_SLOT(slotPostDateChanged(const TQDate&)));
 
 
     m_nameEdit->setFocus();
@@ -296,7 +300,7 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
     d->m_editor = editor;
     slotSetPaymentMethod(d->m_schedule.paymentType());
 
-    connect(m_paymentMethodEdit, TQT_SIGNAL(itemSelected(int)), this, TQT_SLOT(slotSetPaymentMethod(int)));
+    connect(m_paymentMethodEdit, TQ_SIGNAL(itemSelected(int)), this, TQ_SLOT(slotSetPaymentMethod(int)));
   }
 
   return editor;
@@ -358,7 +362,7 @@ const MyMoneySchedule& KEditScheduleDlg::schedule(void) const
           break;
       }
     } else {
-      qDebug("No tabbar found in KEditScheduleDlg::schedule(). Defaulting type to BILL");
+      tqDebug("No tabbar found in KEditScheduleDlg::schedule(). Defaulting type to BILL");
     }
 
     d->m_schedule.setAutoEnter(m_autoEnterEdit->isChecked());
@@ -389,16 +393,16 @@ bool KEditScheduleDlg::focusNextPrevChild(bool next)
 {
   bool  rc = false;
 
-  // qDebug("KEditScheduleDlg::focusNextPrevChild(editmode=%s)", m_inEditMode ? "true" : "false");
+  // tqDebug("KEditScheduleDlg::focusNextPrevChild(editmode=%s)", m_inEditMode ? "true" : "false");
   TQWidget *w = 0;
   TQWidget *currentWidget;
 
   w = tqApp->focusWidget();
   while(w && d->m_tabOrderWidgets.find(w) == -1) {
-    // qDebug("'%s' not in list, use parent", w->className());
+    // tqDebug("'%s' not in list, use parent", w->className());
     w = w->parentWidget();
   }
-  // if(w) qDebug("tab order is at '%s'", w->className());
+  // if(w) tqDebug("tab order is at '%s'", w->className());
   currentWidget = d->m_tabOrderWidgets.current();
   w = next ? d->m_tabOrderWidgets.next() : d->m_tabOrderWidgets.prev();
 
@@ -408,9 +412,9 @@ bool KEditScheduleDlg::focusNextPrevChild(bool next)
     }
 
     if(w != currentWidget
-    && ((w->focusPolicy() & TQ_TabFocus) == TQ_TabFocus)
+    && ((w->focusPolicy() & TQWidget::TabFocus) == TQWidget::TabFocus)
     && w->isVisible() && w->isEnabled()) {
-      // qDebug("Selecting '%s' as focus", w->className());
+      // tqDebug("Selecting '%s' as focus", w->className());
       w->setFocus();
       rc = true;
       break;
