@@ -24,12 +24,12 @@
 #define KMYMONEYPRICEDLG_H
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 class TQListViewItem;
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -39,7 +39,7 @@ class TQListViewItem;
 
 class KMyMoneyPriceDlg : public KMyMoneyPriceDlgDecl
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyPriceDlg(TQWidget* parent, const char *name);
