@@ -19,12 +19,12 @@
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqlabel.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <klineedit.h>
 #include <tdelistview.h>
@@ -47,10 +47,10 @@ KSettingsGeneral::KSettingsGeneral(TQWidget* parent, const char* name) :
   m_viewList->hide();
 
   // setup connections, so that the sort optios get loaded once the edit fields are filled
-  connect(kcfg_StartDate, TQT_SIGNAL(valueChanged(const TQDate&)), this, TQT_SLOT(slotLoadStartDate(const TQDate&)));
+  connect(kcfg_StartDate, TQ_SIGNAL(valueChanged(const TQDate&)), this, TQ_SLOT(slotLoadStartDate(const TQDate&)));
 
   // setup connections, so that changes by the user are forwarded to the (hidden) edit fields
-  connect(m_startDateEdit, TQT_SIGNAL(dateChanged(const TQDate&)), kcfg_StartDate, TQT_SLOT(setDate(const TQDate&)));
+  connect(m_startDateEdit, TQ_SIGNAL(dateChanged(const TQDate&)), kcfg_StartDate, TQ_SLOT(setDate(const TQDate&)));
 }
 
 KSettingsGeneral::~KSettingsGeneral()
@@ -60,7 +60,7 @@ KSettingsGeneral::~KSettingsGeneral()
 void KSettingsGeneral::slotLoadStartDate(const TQDate&)
 {
   // only need this once
-  disconnect(kcfg_StartDate, TQT_SIGNAL(valueChanged(const TQDate&)), this, TQT_SLOT(slotLoadStartDate(const TQDate&)));
+  disconnect(kcfg_StartDate, TQ_SIGNAL(valueChanged(const TQDate&)), this, TQ_SLOT(slotLoadStartDate(const TQDate&)));
   m_startDateEdit->setDate(kcfg_StartDate->date());
 }
 
