@@ -20,10 +20,10 @@
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdelocale.h>
 
@@ -178,7 +178,7 @@ void TransactionMatcher::match(MyMoneyTransaction tm, MyMoneySplit sm, MyMoneyTr
 
   // We use the imported postdate and keep the previous one for unmatch
   if(tm.postDate() != ti.postDate()) {
-    sm.setValue("kmm-orig-postdate", tm.postDate().toString(Qt::ISODate));
+    sm.setValue("kmm-orig-postdate", tm.postDate().toString(TQt::ISODate));
     tm.setPostDate(ti.postDate());
   }
 
@@ -221,7 +221,7 @@ void TransactionMatcher::unmatch(const MyMoneyTransaction& _t, const MyMoneySpli
 
     // restore the postdate if modified
     if(!sm.value("kmm-orig-postdate").isEmpty()) {
-      tm.setPostDate(TQDate::fromString(sm.value("kmm-orig-postdate"), Qt::ISODate));
+      tm.setPostDate(TQDate::fromString(sm.value("kmm-orig-postdate"), TQt::ISODate));
     }
 
     // restore payee if modified
