@@ -23,7 +23,7 @@
 #include <unistd.h>
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqlabel.h>
 #include <tqfile.h>
@@ -38,7 +38,7 @@
 #include <tqobjectlist.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdeversion.h>
 
@@ -137,100 +137,100 @@ KMyMoneyView::KMyMoneyView(TQWidget *parent, const char *name)
     DesktopIcon("home", iconSize));
 
   m_homeView = new KHomeView(m_homeViewFrame, "HomeView");
-  connect(m_homeView, TQT_SIGNAL(ledgerSelected(const TQString&, const TQString&)),
-          this, TQT_SLOT(slotLedgerSelected(const TQString&, const TQString&)));
-  connect(m_homeView, TQT_SIGNAL(scheduleSelected(const TQString&)),
-    this, TQT_SLOT(slotScheduleSelected(const TQString&)));
-  connect(m_homeView, TQT_SIGNAL(reportSelected(const TQString&)),
-    this, TQT_SLOT(slotShowReport(const TQString&)));
+  connect(m_homeView, TQ_SIGNAL(ledgerSelected(const TQString&, const TQString&)),
+          this, TQ_SLOT(slotLedgerSelected(const TQString&, const TQString&)));
+  connect(m_homeView, TQ_SIGNAL(scheduleSelected(const TQString&)),
+    this, TQ_SLOT(slotScheduleSelected(const TQString&)));
+  connect(m_homeView, TQ_SIGNAL(reportSelected(const TQString&)),
+    this, TQ_SLOT(slotShowReport(const TQString&)));
 
   // Page 1
   m_institutionsViewFrame = addVBoxPage( i18n("Institutions"), i18n("Institutions"),
     DesktopIcon("institutions", iconSize));
   addTitleBar(m_institutionsViewFrame, i18n("Institutions"));
   m_institutionsView = new KInstitutionsView(m_institutionsViewFrame, "InstitutionsView");
-  connect(m_institutionsView, TQT_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotSelectAccount(const MyMoneyObject&)));
-  connect(m_institutionsView, TQT_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotSelectInstitution(const MyMoneyObject&)));
-  connect(m_institutionsView, TQT_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
-  connect(m_institutionsView, TQT_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotShowInstitutionContextMenu(const MyMoneyObject&)));
-  connect(m_institutionsView, TQT_SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotInstitutionEdit(const MyMoneyObject&)));
-  connect(m_institutionsView, TQT_SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotAccountOpen(const MyMoneyObject&)));
-  connect(m_institutionsView, TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&)), kmymoney2, TQT_SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyInstitution&)));
-  connect(this, TQT_SIGNAL(reconciliationStarts(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)), m_institutionsView, TQT_SLOT(slotReconcileAccount(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)));
+  connect(m_institutionsView, TQ_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotSelectAccount(const MyMoneyObject&)));
+  connect(m_institutionsView, TQ_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotSelectInstitution(const MyMoneyObject&)));
+  connect(m_institutionsView, TQ_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
+  connect(m_institutionsView, TQ_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotShowInstitutionContextMenu(const MyMoneyObject&)));
+  connect(m_institutionsView, TQ_SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotInstitutionEdit(const MyMoneyObject&)));
+  connect(m_institutionsView, TQ_SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotAccountOpen(const MyMoneyObject&)));
+  connect(m_institutionsView, TQ_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&)), kmymoney2, TQ_SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyInstitution&)));
+  connect(this, TQ_SIGNAL(reconciliationStarts(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)), m_institutionsView, TQ_SLOT(slotReconcileAccount(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)));
 
   // Page 2
   m_accountsViewFrame = addVBoxPage( i18n("Accounts"), i18n("Accounts"),
     DesktopIcon("accounts", iconSize));
   addTitleBar(m_accountsViewFrame, i18n("Accounts"));
   m_accountsView = new KAccountsView(m_accountsViewFrame, "AccountsView");
-  connect(m_accountsView, TQT_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotSelectAccount(const MyMoneyObject&)));
-  connect(m_accountsView, TQT_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotSelectInstitution(const MyMoneyObject&)));
-  connect(m_accountsView, TQT_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotSelectInvestment(const MyMoneyObject&)));
-  connect(m_accountsView, TQT_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
-  connect(m_accountsView, TQT_SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotAccountOpen(const MyMoneyObject&)));
-  connect(m_accountsView, TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQT_SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyAccount&)));
-  connect(this, TQT_SIGNAL(kmmFilePlugin(unsigned int)), m_accountsView, TQT_SLOT(slotUpdateIconPos(unsigned int)));
-  connect(this, TQT_SIGNAL(reconciliationStarts(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)), m_accountsView, TQT_SLOT(slotReconcileAccount(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)));
+  connect(m_accountsView, TQ_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotSelectAccount(const MyMoneyObject&)));
+  connect(m_accountsView, TQ_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotSelectInstitution(const MyMoneyObject&)));
+  connect(m_accountsView, TQ_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotSelectInvestment(const MyMoneyObject&)));
+  connect(m_accountsView, TQ_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
+  connect(m_accountsView, TQ_SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotAccountOpen(const MyMoneyObject&)));
+  connect(m_accountsView, TQ_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQ_SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyAccount&)));
+  connect(this, TQ_SIGNAL(kmmFilePlugin(unsigned int)), m_accountsView, TQ_SLOT(slotUpdateIconPos(unsigned int)));
+  connect(this, TQ_SIGNAL(reconciliationStarts(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)), m_accountsView, TQ_SLOT(slotReconcileAccount(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)));
 
   // Page 3
   m_scheduleViewFrame = addVBoxPage( i18n("Scheduled\ntransactions"), i18n("Bills & Reminders"),
     DesktopIcon("schedule", iconSize));
   addTitleBar(m_scheduleViewFrame, i18n("Scheduled transactions"));
   m_scheduledView = new KScheduledView(m_scheduleViewFrame, "ScheduledView");
-  connect(kmymoney2, TQT_SIGNAL(fileLoaded(const KURL&)), m_scheduledView, TQT_SLOT(slotReloadView()));
-  connect(m_scheduledView, TQT_SIGNAL(scheduleSelected(const MyMoneySchedule&)), kmymoney2, TQT_SLOT(slotSelectSchedule(const MyMoneySchedule&)));
-  connect(m_scheduledView, TQT_SIGNAL(openContextMenu()), kmymoney2, TQT_SLOT(slotShowScheduleContextMenu()));
-  connect(m_scheduledView, TQT_SIGNAL(enterSchedule()), kmymoney2, TQT_SLOT(slotScheduleEnter()));
-  connect(m_scheduledView, TQT_SIGNAL(skipSchedule()), kmymoney2, TQT_SLOT(slotScheduleSkip()));
-  connect(m_scheduledView, TQT_SIGNAL(editSchedule()), kmymoney2, TQT_SLOT(slotScheduleEdit()));
+  connect(kmymoney2, TQ_SIGNAL(fileLoaded(const KURL&)), m_scheduledView, TQ_SLOT(slotReloadView()));
+  connect(m_scheduledView, TQ_SIGNAL(scheduleSelected(const MyMoneySchedule&)), kmymoney2, TQ_SLOT(slotSelectSchedule(const MyMoneySchedule&)));
+  connect(m_scheduledView, TQ_SIGNAL(openContextMenu()), kmymoney2, TQ_SLOT(slotShowScheduleContextMenu()));
+  connect(m_scheduledView, TQ_SIGNAL(enterSchedule()), kmymoney2, TQ_SLOT(slotScheduleEnter()));
+  connect(m_scheduledView, TQ_SIGNAL(skipSchedule()), kmymoney2, TQ_SLOT(slotScheduleSkip()));
+  connect(m_scheduledView, TQ_SIGNAL(editSchedule()), kmymoney2, TQ_SLOT(slotScheduleEdit()));
 
   // Page 4
   m_categoriesViewFrame = addVBoxPage( i18n("Categories"), i18n("Categories"),
     DesktopIcon("categories", iconSize));
   addTitleBar(m_categoriesViewFrame, i18n("Categories"));
   m_categoriesView = new KCategoriesView(m_categoriesViewFrame, "CategoriesView");
-  connect(m_categoriesView, TQT_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotSelectAccount(const MyMoneyObject&)));
-  connect(m_categoriesView, TQT_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotSelectInstitution(const MyMoneyObject&)));
-  connect(m_categoriesView, TQT_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
-  connect(m_categoriesView, TQT_SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotAccountOpen(const MyMoneyObject&)));
-  connect(m_categoriesView, TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQT_SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyAccount&)));
+  connect(m_categoriesView, TQ_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotSelectAccount(const MyMoneyObject&)));
+  connect(m_categoriesView, TQ_SIGNAL(selectObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotSelectInstitution(const MyMoneyObject&)));
+  connect(m_categoriesView, TQ_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
+  connect(m_categoriesView, TQ_SIGNAL(openObject(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotAccountOpen(const MyMoneyObject&)));
+  connect(m_categoriesView, TQ_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQ_SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyAccount&)));
 
   // Page 5
   m_payeesViewFrame = addVBoxPage( i18n("Payees"), i18n("Payees"),
     DesktopIcon("payee", iconSize));
   addTitleBar(m_payeesViewFrame, i18n("Payees"));
   m_payeesView = new KPayeesView(m_payeesViewFrame, "PayeesView");
-  connect(kmymoney2, TQT_SIGNAL(payeeCreated(const TQString&)), m_payeesView, TQT_SLOT(slotSelectPayeeAndTransaction(const TQString&)));
-  connect(kmymoney2, TQT_SIGNAL(payeeRename()), m_payeesView, TQT_SLOT(slotStartRename()));
-  connect(m_payeesView, TQT_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotShowPayeeContextMenu()));
-  connect(m_payeesView, TQT_SIGNAL(selectObjects(const TQValueList<MyMoneyPayee>&)), kmymoney2, TQT_SLOT(slotSelectPayees(const TQValueList<MyMoneyPayee>&)));
-  connect(m_payeesView, TQT_SIGNAL(transactionSelected(const TQString&, const TQString&)),
-          this, TQT_SLOT(slotLedgerSelected(const TQString&, const TQString&)));
+  connect(kmymoney2, TQ_SIGNAL(payeeCreated(const TQString&)), m_payeesView, TQ_SLOT(slotSelectPayeeAndTransaction(const TQString&)));
+  connect(kmymoney2, TQ_SIGNAL(payeeRename()), m_payeesView, TQ_SLOT(slotStartRename()));
+  connect(m_payeesView, TQ_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotShowPayeeContextMenu()));
+  connect(m_payeesView, TQ_SIGNAL(selectObjects(const TQValueList<MyMoneyPayee>&)), kmymoney2, TQ_SLOT(slotSelectPayees(const TQValueList<MyMoneyPayee>&)));
+  connect(m_payeesView, TQ_SIGNAL(transactionSelected(const TQString&, const TQString&)),
+          this, TQ_SLOT(slotLedgerSelected(const TQString&, const TQString&)));
 
   // Page 6
   m_ledgerViewFrame = addVBoxPage( i18n("Ledgers"), i18n("Ledgers"),
     DesktopIcon("ledger", iconSize));
   m_ledgerView = new TDEGlobalLedgerView(m_ledgerViewFrame, "GlobalLedgerView");
-  connect(m_ledgerView, TQT_SIGNAL(accountSelected(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotSelectAccount(const MyMoneyObject&)));
-  connect(m_ledgerView, TQT_SIGNAL(openContextMenu()), kmymoney2, TQT_SLOT(slotShowTransactionContextMenu()));
-  connect(m_ledgerView, TQT_SIGNAL(transactionsSelected(const KMyMoneyRegister::SelectedTransactions&)), kmymoney2, TQT_SLOT(slotSelectTransactions(const KMyMoneyRegister::SelectedTransactions&)));
-  connect(m_ledgerView, TQT_SIGNAL(newTransaction()), kmymoney2, TQT_SLOT(slotTransactionsNew()));
-  connect(m_ledgerView, TQT_SIGNAL(cancelOrEndEdit(bool&)), kmymoney2, TQT_SLOT(slotTransactionsCancelOrEnter(bool&)));
-  connect(m_ledgerView, TQT_SIGNAL(startEdit()), kmymoney2, TQT_SLOT(slotTransactionsEdit()));
-  connect(m_ledgerView, TQT_SIGNAL(endEdit()), kmymoney2, TQT_SLOT(slotTransactionsEnter()));
-  connect(m_ledgerView, TQT_SIGNAL(toggleReconciliationFlag()), kmymoney2, TQT_SLOT(slotToggleReconciliationFlag()));
-  connect(this, TQT_SIGNAL(reconciliationStarts(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)), m_ledgerView, TQT_SLOT(slotSetReconcileAccount(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)));
-  connect(kmymoney2, TQT_SIGNAL(selectAllTransactions()), m_ledgerView, TQT_SLOT(slotSelectAllTransactions()));
+  connect(m_ledgerView, TQ_SIGNAL(accountSelected(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotSelectAccount(const MyMoneyObject&)));
+  connect(m_ledgerView, TQ_SIGNAL(openContextMenu()), kmymoney2, TQ_SLOT(slotShowTransactionContextMenu()));
+  connect(m_ledgerView, TQ_SIGNAL(transactionsSelected(const KMyMoneyRegister::SelectedTransactions&)), kmymoney2, TQ_SLOT(slotSelectTransactions(const KMyMoneyRegister::SelectedTransactions&)));
+  connect(m_ledgerView, TQ_SIGNAL(newTransaction()), kmymoney2, TQ_SLOT(slotTransactionsNew()));
+  connect(m_ledgerView, TQ_SIGNAL(cancelOrEndEdit(bool&)), kmymoney2, TQ_SLOT(slotTransactionsCancelOrEnter(bool&)));
+  connect(m_ledgerView, TQ_SIGNAL(startEdit()), kmymoney2, TQ_SLOT(slotTransactionsEdit()));
+  connect(m_ledgerView, TQ_SIGNAL(endEdit()), kmymoney2, TQ_SLOT(slotTransactionsEnter()));
+  connect(m_ledgerView, TQ_SIGNAL(toggleReconciliationFlag()), kmymoney2, TQ_SLOT(slotToggleReconciliationFlag()));
+  connect(this, TQ_SIGNAL(reconciliationStarts(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)), m_ledgerView, TQ_SLOT(slotSetReconcileAccount(const MyMoneyAccount&, const TQDate&, const MyMoneyMoney&)));
+  connect(kmymoney2, TQ_SIGNAL(selectAllTransactions()), m_ledgerView, TQ_SLOT(slotSelectAllTransactions()));
 
   // Page 7
   m_investmentViewFrame = addVBoxPage( i18n("Investments"), i18n("Investments"),
     DesktopIcon("investments", iconSize));
   addTitleBar(m_investmentViewFrame, i18n("Investments"));
   m_investmentView = new KInvestmentView(m_investmentViewFrame, "InvestmentView");
-  connect(m_investmentView, TQT_SIGNAL(accountSelected(const TQString&, const TQString&)),
-      this, TQT_SLOT(slotLedgerSelected(const TQString&, const TQString&)));
-  connect(m_investmentView, TQT_SIGNAL(accountSelected(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotSelectAccount(const MyMoneyObject&)));
-  connect(m_investmentView, TQT_SIGNAL(investmentRightMouseClick()), kmymoney2, TQT_SLOT(slotShowInvestmentContextMenu()));
+  connect(m_investmentView, TQ_SIGNAL(accountSelected(const TQString&, const TQString&)),
+      this, TQ_SLOT(slotLedgerSelected(const TQString&, const TQString&)));
+  connect(m_investmentView, TQ_SIGNAL(accountSelected(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotSelectAccount(const MyMoneyObject&)));
+  connect(m_investmentView, TQ_SIGNAL(investmentRightMouseClick()), kmymoney2, TQ_SLOT(slotShowInvestmentContextMenu()));
 
   // Page 8
   m_reportsViewFrame = addVBoxPage(i18n("Reports"), i18n("Reports"),
@@ -242,10 +242,10 @@ KMyMoneyView::KMyMoneyView(TQWidget *parent, const char *name)
     DesktopIcon("budget", iconSize));
   addTitleBar(m_budgetViewFrame, i18n("Budgets"));
   m_budgetView = new KBudgetView(m_budgetViewFrame, "BudgetView");
-  connect(kmymoney2, TQT_SIGNAL(fileLoaded(const KURL&)), m_budgetView, TQT_SLOT(slotRefreshView()));
-  connect(m_budgetView, TQT_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotShowBudgetContextMenu()));
-  connect(m_budgetView, TQT_SIGNAL(selectObjects(const TQValueList<MyMoneyBudget>&)), kmymoney2, TQT_SLOT(slotSelectBudget(const TQValueList<MyMoneyBudget>&)));
-  connect(kmymoney2, TQT_SIGNAL(budgetRename()), m_budgetView, TQT_SLOT(slotStartRename()));
+  connect(kmymoney2, TQ_SIGNAL(fileLoaded(const KURL&)), m_budgetView, TQ_SLOT(slotRefreshView()));
+  connect(m_budgetView, TQ_SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney2, TQ_SLOT(slotShowBudgetContextMenu()));
+  connect(m_budgetView, TQ_SIGNAL(selectObjects(const TQValueList<MyMoneyBudget>&)), kmymoney2, TQ_SLOT(slotSelectBudget(const TQValueList<MyMoneyBudget>&)));
+  connect(kmymoney2, TQ_SIGNAL(budgetRename()), m_budgetView, TQ_SLOT(slotStartRename()));
 
   // Page 10
   m_forecastViewFrame = addVBoxPage( i18n("Forecast"), i18n("Forecast"),
@@ -266,7 +266,7 @@ KMyMoneyView::KMyMoneyView(TQWidget *parent, const char *name)
   // select the page first, before connecting the aboutToShow signal
   // because we don't want to override the information stored in the config file
   showPage(0);
-  connect(this, TQT_SIGNAL(aboutToShowPage(TQWidget*)), this, TQT_SLOT(slotRememberPage(TQWidget*)));
+  connect(this, TQ_SIGNAL(aboutToShowPage(TQWidget*)), this, TQ_SLOT(slotRememberPage(TQWidget*)));
 
   m_inConstructor = false;
 }
@@ -632,16 +632,16 @@ bool KMyMoneyView::readFile(const KURL& url)
         ::timetrace("detected GPG");
         if(KGPGFile::GPGAvailable()) {
           ::timetrace("have GPG");
-          qfile = TQT_TQIODEVICE(new KGPGFile(filename));
+          qfile = new KGPGFile(filename);
           haveAt = false;
           isEncrypted = true;
         } else {
           KMessageBox::sorry(this, TQString("<qt>%1</qt>"). arg(i18n("GPG is not available for decryption of file <b>%1</b>").arg(filename)));
-          qfile = TQT_TQIODEVICE(new TQFile(file.name()));
+          qfile = new TQFile(file.name());
         }
       } else {
         // we can't use file directly, as we delete qfile later on
-        qfile = TQT_TQIODEVICE(new TQFile(file.name()));
+        qfile = new TQFile(file.name());
       }
 
       ::timetrace("open file");
@@ -969,7 +969,7 @@ bool KMyMoneyView::initializeStorage()
 
 void KMyMoneyView::saveToLocalFile(TQFile* qfile, IMyMoneyStorageFormat* pWriter, bool plaintext, const TQString& keyList)
 {
-  TQIODevice *dev = TQT_TQIODEVICE(qfile);
+  TQIODevice *dev = qfile;
   KFilterBase *base = 0;
   TQIODevice *statusDevice = dev;
 
@@ -1027,7 +1027,7 @@ void KMyMoneyView::saveToLocalFile(TQFile* qfile, IMyMoneyStorageFormat* pWriter
       }
       MyMoneyFile::instance()->setValue("kmm-encryption-key", keyList);
     }
-    statusDevice = dev = TQT_TQIODEVICE(kgpg);
+    statusDevice = dev = kgpg;
     if(!dev || !dev->open(IO_WriteOnly)) {
       MyMoneyFile::instance()->blockSignals(blocked);
       delete dev;
@@ -1039,7 +1039,7 @@ void KMyMoneyView::saveToLocalFile(TQFile* qfile, IMyMoneyStorageFormat* pWriter
     base = KFilterBase::findFilterByMimeType( COMPRESSION_MIME_TYPE );
     if(base) {
       qfile->close();
-      base->setDevice(TQT_TQIODEVICE(qfile), false);
+      base->setDevice(qfile, false);
       // we need to reopen the file to set the mode inside the filter stuff
       dev = new KFilterDev(base, true);
       if(!dev || !dev->open(IO_WriteOnly)) {
@@ -1282,7 +1282,7 @@ void KMyMoneyView::selectBaseCurrency(void)
   // check if we have a base currency. If not, we need to select one
   if(file->baseCurrency().id().isEmpty()) {
     KCurrencyEditDlg dlg(this, "CurrencyEditDlg");
-    connect(&dlg, TQT_SIGNAL(selectBaseCurrency(const MyMoneySecurity&)), this, TQT_SLOT(slotSetBaseCurrency(const MyMoneySecurity&)));
+    connect(&dlg, TQ_SIGNAL(selectBaseCurrency(const MyMoneySecurity&)), this, TQ_SLOT(slotSetBaseCurrency(const MyMoneySecurity&)));
     dlg.exec();
   }
 
@@ -1591,13 +1591,13 @@ void KMyMoneyView::viewAccountList(const TQString& /*selectAccount*/)
 void KMyMoneyView::slotRefreshViews()
 {
   // turn off sync between ledger and investment view
-  disconnect(m_investmentView, TQT_SIGNAL(accountSelected(const MyMoneyObject&)), m_ledgerView, TQT_SLOT(slotSelectAccount(const MyMoneyObject&)));
-  disconnect(m_ledgerView, TQT_SIGNAL(accountSelected(const MyMoneyObject&)), m_investmentView, TQT_SLOT(slotSelectAccount(const MyMoneyObject&)));
+  disconnect(m_investmentView, TQ_SIGNAL(accountSelected(const MyMoneyObject&)), m_ledgerView, TQ_SLOT(slotSelectAccount(const MyMoneyObject&)));
+  disconnect(m_ledgerView, TQ_SIGNAL(accountSelected(const MyMoneyObject&)), m_investmentView, TQ_SLOT(slotSelectAccount(const MyMoneyObject&)));
 
   // TODO turn sync between ledger and investment view if selected by user
   if(KMyMoneyGlobalSettings::syncLedgerInvestment()) {
-    connect(m_investmentView, TQT_SIGNAL(accountSelected(const MyMoneyObject&)), m_ledgerView, TQT_SLOT(slotSelectAccount(const MyMoneyObject&)));
-    connect(m_ledgerView, TQT_SIGNAL(accountSelected(const MyMoneyObject&)), m_investmentView, TQT_SLOT(slotSelectAccount(const MyMoneyObject&)));
+    connect(m_investmentView, TQ_SIGNAL(accountSelected(const MyMoneyObject&)), m_ledgerView, TQ_SLOT(slotSelectAccount(const MyMoneyObject&)));
+    connect(m_ledgerView, TQ_SIGNAL(accountSelected(const MyMoneyObject&)), m_investmentView, TQ_SLOT(slotSelectAccount(const MyMoneyObject&)));
   }
 
   showTitleBar(KMyMoneyGlobalSettings::showTitleBar());
@@ -2187,13 +2187,13 @@ KMyMoneyViewBase* KMyMoneyView::addPage(const TQString& title, const TQString& i
 /* ------------------------------------------------------------------------ */
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqlayout.h>
 #include <tqvbox.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 // ----------------------------------------------------------------------------
 // Project Includes
