@@ -21,9 +21,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqpushbutton.h>
 #include <tqcombobox.h>
@@ -43,7 +46,7 @@
 #include <tqmap.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdeglobal.h>
 #include <tdelocale.h>
@@ -371,39 +374,39 @@ KPayeesView::KPayeesView(TQWidget *parent, const char *name ) :
                     i18n("Use this to accept the modified data."));
   m_updateButton->setGuiItem(updateButtenItem);
 
-  connect(m_payeesList, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(slotSelectPayee()));
-  connect(m_payeesList, TQT_SIGNAL(itemRenamed(TQListViewItem*,int,const TQString&)), this, TQT_SLOT(slotRenamePayee(TQListViewItem*,int,const TQString&)));
+  connect(m_payeesList, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(slotSelectPayee()));
+  connect(m_payeesList, TQ_SIGNAL(itemRenamed(TQListViewItem*,int,const TQString&)), this, TQ_SLOT(slotRenamePayee(TQListViewItem*,int,const TQString&)));
 
-  connect(addressEdit, TQT_SIGNAL(textChanged()), this, TQT_SLOT(slotPayeeDataChanged()));
-  connect(postcodeEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotPayeeDataChanged()));
-  connect(telephoneEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotPayeeDataChanged()));
-  connect(emailEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotPayeeDataChanged()));
-  connect(notesEdit, TQT_SIGNAL(textChanged()), this, TQT_SLOT(slotPayeeDataChanged()));
-  connect(matchKeyEditList, TQT_SIGNAL(changed()), this, TQT_SLOT(slotKeyListChanged()));
+  connect(addressEdit, TQ_SIGNAL(textChanged()), this, TQ_SLOT(slotPayeeDataChanged()));
+  connect(postcodeEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotPayeeDataChanged()));
+  connect(telephoneEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotPayeeDataChanged()));
+  connect(emailEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotPayeeDataChanged()));
+  connect(notesEdit, TQ_SIGNAL(textChanged()), this, TQ_SLOT(slotPayeeDataChanged()));
+  connect(matchKeyEditList, TQ_SIGNAL(changed()), this, TQ_SLOT(slotKeyListChanged()));
 
-  connect(radioNoMatch, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotPayeeDataChanged()));
-  connect(radioNameMatch, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotPayeeDataChanged()));
-  connect(radioKeyMatch, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotPayeeDataChanged()));
-  connect(checkMatchIgnoreCase, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotPayeeDataChanged()));
+  connect(radioNoMatch, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotPayeeDataChanged()));
+  connect(radioNameMatch, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotPayeeDataChanged()));
+  connect(radioKeyMatch, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotPayeeDataChanged()));
+  connect(checkMatchIgnoreCase, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotPayeeDataChanged()));
 
-  connect(checkEnableDefaultAccount, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotPayeeDataChanged()));
-  connect(comboDefaultAccount, TQT_SIGNAL(accountSelected(const TQString&)), this, TQT_SLOT(slotPayeeDataChanged()));
-  connect(buttonSelectMyAccount, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotChooseDefaultAccount()));
+  connect(checkEnableDefaultAccount, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotPayeeDataChanged()));
+  connect(comboDefaultAccount, TQ_SIGNAL(accountSelected(const TQString&)), this, TQ_SLOT(slotPayeeDataChanged()));
+  connect(buttonSelectMyAccount, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotChooseDefaultAccount()));
 
-  connect(m_updateButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotUpdatePayee()));
-  connect(m_helpButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotHelp()));
+  connect(m_updateButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotUpdatePayee()));
+  connect(m_helpButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotHelp()));
 
-  connect(m_payeesList, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)), this, TQT_SLOT(slotOpenContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
+  connect(m_payeesList, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)), this, TQ_SLOT(slotOpenContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
 
-//  connect(m_payeesList, TQT_SIGNAL(rightButtonClicked(TQListViewItem* , const TQPoint&, int)),
-//    this, TQT_SLOT(slotOpenContextMenu(TQListViewItem*)));
+//  connect(m_payeesList, TQ_SIGNAL(rightButtonClicked(TQListViewItem* , const TQPoint&, int)),
+//    this, TQ_SLOT(slotOpenContextMenu(TQListViewItem*)));
 
-  connect(m_transactionView, TQT_SIGNAL(doubleClicked(TQListViewItem*)),
-          this, TQT_SLOT(slotTransactionDoubleClicked(TQListViewItem*)));
+  connect(m_transactionView, TQ_SIGNAL(doubleClicked(TQListViewItem*)),
+          this, TQ_SLOT(slotTransactionDoubleClicked(TQListViewItem*)));
 
-  connect(m_tabWidget, TQT_SIGNAL(currentChanged(TQWidget*)), this, TQT_SLOT(rearrange(void)));
+  connect(m_tabWidget, TQ_SIGNAL(currentChanged(TQWidget*)), this, TQ_SLOT(rearrange(void)));
 
-  connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), this, TQT_SLOT(slotLoadPayees()));
+  connect(MyMoneyFile::instance(), TQ_SIGNAL(dataChanged()), this, TQ_SLOT(slotLoadPayees()));
 }
 
 KPayeesView::~KPayeesView()
@@ -419,7 +422,7 @@ void KPayeesView::slotQueueUpdate(void)
   m_updatesQueued++;
   // The TDEListViewSearchLineWidget has an internal timer for update purposes
   // of 200 ms, so we should be safe with 250 ms here
-  TQTimer::singleShot(250, this, TQT_SLOT(slotActivateUpdate()));
+  TQTimer::singleShot(250, this, TQ_SLOT(slotActivateUpdate()));
 }
 
 void KPayeesView::slotActivateUpdate(void)
@@ -763,7 +766,7 @@ void KPayeesView::showTransactions(void)
   // is incorrect. If the widget is visible, resizing works correctly.
   // So, we let the dialog show up and resize it then. It's not really
   // clean, but the only way I got the damned thing working.
-  TQTimer::singleShot(50, this, TQT_SLOT(rearrange()));
+  TQTimer::singleShot(50, this, TQ_SLOT(rearrange()));
 }
 
 void KPayeesView::slotKeyListChanged(void)
@@ -904,7 +907,7 @@ void KPayeesView::show(void)
   // If you want to learn about the details, see the source of TDEListViewSearchLineWidget's
   // constructor
   if(m_needConnection) {
-    connect(m_searchWidget->searchLine(), TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotQueueUpdate(void)));
+    connect(m_searchWidget->searchLine(), TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotQueueUpdate(void)));
     m_needConnection = false;
   }
 
@@ -914,7 +917,7 @@ void KPayeesView::show(void)
   }
 
   // fixup the layout
-  TQTimer::singleShot(0, this, TQT_SLOT(rearrange()));
+  TQTimer::singleShot(0, this, TQ_SLOT(rearrange()));
 
   // don't forget base class implementation
   KPayeesViewDecl::show();
@@ -928,7 +931,7 @@ void KPayeesView::slotLoadPayees(void)
 {
   if(isVisible()) {
     if(m_inSelection)
-      TQTimer::singleShot(0, this, TQT_SLOT(slotLoadPayees()));
+      TQTimer::singleShot(0, this, TQ_SLOT(slotLoadPayees()));
     else
       loadPayees();
   } else {
