@@ -15,10 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <locale.h>
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqpixmap.h>
 #include <tqbitmap.h>
@@ -28,7 +32,7 @@
 #include <tqlabel.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdelocale.h>
 #include <tdelistview.h>
@@ -172,8 +176,8 @@ GeneralPage::GeneralPage(Wizard* wizard, const char* name) :
 {
   m_userNameEdit->setFocus();
   TDEABC::StdAddressBook *ab = TDEABC::StdAddressBook::self(true);
-  connect(ab, TQT_SIGNAL(addressBookChanged(AddressBook*)), this, TQT_SLOT(slotAddressBookLoaded()));
-  connect(m_loadAddressButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotLoadFromKABC()));
+  connect(ab, TQ_SIGNAL(addressBookChanged(AddressBook*)), this, TQ_SLOT(slotAddressBookLoaded()));
+  connect(m_loadAddressButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotLoadFromKABC()));
   m_loadAddressButton->setEnabled(false);
 }
 
@@ -276,8 +280,8 @@ AccountPage::AccountPage(Wizard* wizard, const char* name) :
   WizardPage<Wizard>(stepCount, this, wizard, name)       // don't inc. the step count here
 {
   m_mandatoryGroup->add(m_accountNameEdit);
-  connect(m_mandatoryGroup, TQT_SIGNAL(stateChanged()), object(), TQT_SIGNAL(completeStateChanged()));
-  connect(m_haveCheckingAccountButton, TQT_SIGNAL(toggled(bool)), object(), TQT_SIGNAL(completeStateChanged()));
+  connect(m_mandatoryGroup, TQ_SIGNAL(stateChanged()), object(), TQ_SIGNAL(completeStateChanged()));
+  connect(m_haveCheckingAccountButton, TQ_SIGNAL(toggled(bool)), object(), TQ_SIGNAL(completeStateChanged()));
   m_accountNameEdit->setFocus();
   m_openingDateEdit->setDate(TQDate(TQDate::currentDate().year(),1,1));
 }
@@ -312,7 +316,7 @@ PreferencePage::PreferencePage(Wizard* wizard, const char* name) :
   KPreferencePageDecl(wizard),
   WizardPage<Wizard>(stepCount++, this, wizard, name)
 {
-  connect(m_openConfigButton, TQT_SIGNAL(clicked()), kmymoney2, TQT_SLOT(slotSettings()));
+  connect(m_openConfigButton, TQ_SIGNAL(clicked()), kmymoney2, TQ_SLOT(slotSettings()));
 }
 
 KMyMoneyWizardPage* PreferencePage::nextPage(void) const
@@ -325,7 +329,7 @@ FilePage::FilePage(Wizard* wizard, const char* name) :
   WizardPage<Wizard>(stepCount++, this, wizard, name)
 {
   m_mandatoryGroup->add(m_dataFileEdit->lineEdit());
-  connect(m_mandatoryGroup, TQT_SIGNAL(stateChanged()), object(), TQT_SIGNAL(completeStateChanged()));
+  connect(m_mandatoryGroup, TQ_SIGNAL(stateChanged()), object(), TQ_SIGNAL(completeStateChanged()));
 
   KUser user;
   m_dataFileEdit->setShowLocalProtocol(false);
@@ -361,3 +365,4 @@ bool FilePage::isComplete(void) const
 }
 
 #include "knewuserwizard.moc"
+#include "knewuserwizard_p.moc"
