@@ -22,7 +22,7 @@
 #include <tqobject.h>
 #include <tqstring.h>
 #include <tqstringlist.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 /**
   * @author Thomas Baumgart
@@ -56,7 +56,7 @@ class TDEProcess;
   * GPGAvailable(). Other, more general methods such as open(), close() and flush() are
   * not shown in the above picture.
   */
-class KDE_EXPORT KGPGFile : public TQObject, public TQFile
+class TDE_EXPORT KGPGFile : public TQObject, public TQFile
 {
   TQ_OBJECT
   
